@@ -1,5 +1,21 @@
 from typing import Union, List
 
+import logging
+
+if __name__ == "main":
+    logging.basicConfig(level=logging.DEBUG)
+else:
+    logging.basicConfig(level=logging.INFO)  # TODO read from config
+
+from pythonjsonlogger import jsonlogger
+
+logger = logging.getLogger()
+
+formatter = jsonlogger.JsonFormatter()
+
+for handler in logger.handlers:
+    handler.setFormatter(formatter)
+
 import os
 import json
 import uvicorn
@@ -41,11 +57,16 @@ def predict(body: generatedProjectNameInputs) -> List[generatedProjectNameOutput
     predict api
     '''
     data = body.dict()
+    logger.info({"message": "predict invoked", "data": json.dumps(data)})
     print('data', data)
 
     # call model here
-    p = generatedProjectNamePipeline()
-    output: List[generatedProjectNameOutputs] = p.execute(**data)
+    try:
+        p = generatedProjectNamePipeline()
+        output: List[generatedProjectNameOutputs] = p.execute(**data)
+    except Exception as ex:
+        logger.exception(msg=data, exc_info=True)
+        output = {'error': {'request': data}}
     # call model here
     return output
 
@@ -55,28 +76,38 @@ def parse(body: generatedProjectNameInputs) -> List[generatedProjectNameOutputs]
     parse api
     '''
     data = body.dict()
+    logger.info({"message": "parse invoked", "data": json.dumps(data)})
     print('data', data)
 
     # call model here
-    p = generatedProjectNamePipeline()
-    output: List[generatedProjectNameOutputs] = p.execute(**data)
+    try:
+        p = generatedProjectNamePipeline()
+        output: List[generatedProjectNameOutputs] = p.execute(**data)
+    except Exception as ex:
+        logger.exception(msg=data, exc_info=True)
+        output = {'error': {'request': data}}
     # call model here
     return output
 
 @app.post('/test')
-def test(body: List[generatedProjectNameInputs]) -> List[generatedProjectNameOutputs]:
+def test(body: List) -> List[generatedProjectNameOutputs]:
     '''
     test api
     '''
+    logger.info({"message": "predict invoked", "test": json.dumps(body)})
     print('body',body)
 
     # call model here
-    p = generatedProjectNamePipeline()
-    output: List[generatedProjectNameOutputs] = []
-    for item in body:
-        output.extend(p.execute(**item.dict()))
-    # output: List[generatedProjectNameOutputs] = p.execute(**body)
+    try:
+        p = generatedProjectNamePipeline()
+        output: List[generatedProjectNameOutputs] = []
+        for item in body:
+            output.append(p.execute(**item))
+    except Exception as ex:
+        logger.exception(msg=body, exc_info=True)
+        output = {'error': {'request': body}}
     # call model here
+
     return output
 
 @app.get("/livenessprobe")
