@@ -1,8 +1,8 @@
 from dsframework.utils.regex_handler import RegexHandler
-from generatedDirectory.pipeline import generatedProjectNamePipeline
+from generatedMainDirectory.pipeline import generatedProjectNamePipeline
 from dsframework.testable.tester_base import TesterBase
-from generatedDirectory.tester import generatedProjectNameDataset
-from generatedDirectory.tester import generatedProjectNameReporter
+# from generatedMainDirectory.tester import generatedProjectNameDataset
+from generatedMainDirectory.tester import generatedProjectNameReporter
 import pandas as pd
 import string
 from tqdm import tqdm
@@ -25,15 +25,15 @@ class generatedClass(TesterBase):
     def build(self, path:str='', load_samples=False):
         path, _ = self.convert_dataset_to_seg_format(path)
         self.init_pipeline()
-        self.init_dataset(path=path, load_samples=load_samples)
+        # self.init_dataset(path=path, load_samples=load_samples)
         self.init_reporter()
         self.ready = True
 
     def init_pipeline(self, *args, **kwargs):
         self.pipeline = generatedProjectNamePipeline.getInstance()
 
-    def init_dataset(self, path='',  do_convert=False, load_samples=False, *args, **kwargs):
-        self.dataset = generatedProjectNameDataset(path=path, load_samples=load_samples)
+    # def init_dataset(self, path='',  do_convert=False, load_samples=False, *args, **kwargs):
+    #     self.dataset = generatedProjectNameDataset(path=path, load_samples=load_samples)
 
     def init_reporter(self, path='', report_header='Signature Parser Analysis Report'):
         self.set_report_header(report_header)
