@@ -4,6 +4,15 @@ from setuptools import find_packages, setup
 with open('requirements.txt') as f:
     required = f.read().splitlines()
 
+def package_files(directory):
+    paths = []
+    for (path, directories, filenames) in os.walk(directory):
+        for filename in filenames:
+            paths.append(os.path.join('..', path, filename))
+    return paths
+
+extra_files = package_files('cli/tester/deploy_files')
+
 setup(
     name='dsFramework',
     py_modules=['api_cli'],
@@ -28,12 +37,12 @@ setup(
         'dsframework.base.tester',
         'dsframework.base.trainer',
     ],
-    package_data={'': ['config.json', 'cors_allowed_origins.json']},
+    package_data={'': ['config.json', 'cors_allowed_origins.json', '.gitignore'] + extra_files},
     entry_points='''
         [console_scripts]
         dsf-cli=api_cli:cli
     ''',
-    version='0.1.31',
+    version='0.1.36',
     description='data science framework library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
